@@ -17,10 +17,10 @@
  * along with QCAD.
  */
 
-include("../File.js");
+include("scripts/File/File.js");
 include("scripts/sprintf.js");
 if (RSettings.isGuiEnabled() && typeof(PrintPreview)=="undefined") {
-    include("../PrintPreview/PrintPreview.js");
+    include("scripts/File/PrintPreview/PrintPreview.js");
 }
 if (typeof(PageSettings)=="undefined") {
     include("scripts/Edit/DrawingPreferences/PageSettings/PageSettings.js");
@@ -70,13 +70,32 @@ Print.prototype.beginEvent = function() {
 
 /**
  * Prints the given document.
+ *
+ * \param pdfFile Name of PDF file
+ * \param printerName Name of printer to print to or "" for default printer
  */
-Print.prototype.print = function(pdfFile) {
-    var printer = new QPrinter(QPrinter.HighResolution);
+Print.prototype.print = function(pdfFile, printerName) {
+    var printer = undefined;
 
-    if (isString(pdfFile)) {
-        printer.setOutputFormat(QPrinter.PdfFormat);
-        printer.setOutputFileName(pdfFile);
+    // print directly to given printer or default printer:
+    if (!isNull(printerName)) {
+        if (printerName==="") {
+            printerName = getDefaultPrinterName();
+        }
+        printer = createPrinter(printerName);
+        if (isNull(printer)) {
+            qWarning("invalid printer name: ", printerName);
+            printer = undefined;
+        }
+    }
+
+    if (isNull(printer)) {
+        printer = new QPrinter(QPrinter.HighResolution);
+
+        if (isString(pdfFile)) {
+            printer.setOutputFormat(QPrinter.PdfFormat);
+            printer.setOutputFileName(pdfFile);
+        }
     }
 
     var paperSizeEnum = Print.getPaperSizeEnum(this.document);
@@ -98,10 +117,12 @@ Print.prototype.print = function(pdfFile) {
         printer.setColorMode(QPrinter.GrayScale);
     }
 
-    // show printer dialog if we are not printing to a PDF file:
-    if (!isString(pdfFile)) {
+    // show printer dialog if we are not printing to a PDF file
+    // or running as command line tool:
+    var appWin = EAction.getMainWindow();
+    if (!isString(pdfFile) && !isNull(appWin) && isNull(printerName)) {
         Print.cancel = false;
-        Print.printDialog = new QPrintDialog(printer, EAction.getMainWindow());
+        Print.printDialog = new QPrintDialog(printer, appWin);
 
         if (RSettings.isQt(5)) {
             Print.printDialog.rejected.connect(function() { Print.cancel = true; });
@@ -185,7 +206,7 @@ Print.prototype.print = function(pdfFile) {
         printer.paperRect().height() / heightInMM
     );
 
-    // printer calibration goes here (future use):
+    // printer calibration:
     printerFactor.x *= RSettings.getDoubleValue(printer.printerName() + "/FactorX", 1.0);
     printerFactor.y *= RSettings.getDoubleValue(printer.printerName() + "/FactorY", 1.0);
 
@@ -308,6 +329,8 @@ Print.prototype.printPage = function(painter, rect) {
             new RVector(rect.x()+rect.width(), rect.y()+rect.height())
         )
     );
+
+    this.view.paintOverlay(painter);
 };
 
 /**
