@@ -17,7 +17,7 @@
  * along with QCAD.
  */
 
-include("../Widgets.js");
+include("scripts/Widgets/Widgets.js");
 include("scripts/WidgetFactory.js");
 
 /**
@@ -461,6 +461,18 @@ BlockList.applyPreferences = function(doc, mdiChild) {
     WidgetFactory.initList(blockList, "BlockList");
 };
 
+/**
+ * \return Active item.
+ */
+BlockList.getActiveItem = function() {
+    var appWin = RMainWindowQt.getMainWindow();
+    var blockList = appWin.findChild("BlockList");
+    if (isNull(blockList)) {
+        return undefined;
+    }
+
+    return blockList.getActiveItem();
+};
 
 /**
  * Shows / hides the block list.
